module.exports = defineTest({
	description: 'correctly resolves the prototype of the super class when accessing properties'
});
